#include <QtGui/QApplication>

#include <rx/columbus/ColumbusController.h>

#include "ui/MainWindow.h"

int main(int argc, char *argv[])
{
    QApplication::setOrganizationDomain("rubyx.co.uk");
    QApplication::setOrganizationName("rx");
    QApplication::setApplicationName("columbus");
    QApplication::setApplicationVersion("0.8.1");

    QApplication            application (argc, argv);
    ColumbusController   controller;

    MainWindow              window;
    window.initialize(&controller);

    controller.initialize();

#if defined(Q_WS_MAEMO_5)
    window.showFullScreen();
#else
    window.setFixedSize(800, 480);
    window.show();
#endif

    return application.exec();
}
